@@ -1,7 +1,8 @@
 /* $RoughId: sha1init.c,v 1.2 2001/07/13 19:49:10 knu Exp $ */
-/* $Id: sha1init.c 34816 2012-02-25 20:37:12Z naruse $ */
+/* $Id: sha1init.c 52797 2015-11-30 12:08:16Z usa $ */
 
-#include "digest.h"
+#include <ruby/ruby.h>
+#include "../digest.h"
 #if defined(HAVE_OPENSSL_SHA_H)
 #include "sha1ossl.h"
 #else
