@@ -1,13 +1,18 @@
 /* $RoughId: sha2init.c,v 1.3 2001/07/13 20:00:43 knu Exp $ */
-/* $Id: sha2init.c 11708 2007-02-12 23:01:19Z shyouhei $ */
+/* $Id: sha2init.c 52797 2015-11-30 12:08:16Z usa $ */
 
-#include "digest.h"
+#include <ruby/ruby.h>
+#include "../digest.h"
+#if defined(SHA2_USE_OPENSSL)
+#include "sha2ossl.h"
+#else
 #include "sha2.h"
+#endif
 
 #define FOREACH_BITLEN(func)	func(256) func(384) func(512)
 
 #define DEFINE_ALGO_METADATA(bitlen) \
-static rb_digest_metadata_t sha##bitlen = { \
+static const rb_digest_metadata_t sha##bitlen = { \
     RUBY_DIGEST_API_VERSION, \
     SHA##bitlen##_DIGEST_LENGTH, \
     SHA##bitlen##_BLOCK_LENGTH, \
@@ -46,7 +51,7 @@ Init_sha2()
     cDigest_SHA##bitlen = rb_define_class_under(mDigest, "SHA" #bitlen, cDigest_Base); \
 \
     rb_ivar_set(cDigest_SHA##bitlen, id_metadata, \
-      Data_Wrap_Struct(rb_cObject, 0, 0, &sha##bitlen));
+      Data_Wrap_Struct(rb_cObject, 0, 0, (void *)&sha##bitlen));
 
     FOREACH_BITLEN(DEFINE_ALGO_CLASS)
 }
