@@ -616,7 +616,7 @@ class Tester < Test::Unit::TestCase
   def test_stream
     c = Listener.new
     Document.parse_stream( File.new(fixture_path("documentation.xml")), c )
-    assert(c.ts, "Stream parsing apparantly didn't parse the whole file")
+    assert(c.ts, "Stream parsing apparently didn't parse the whole file")
     assert(c.te, "Stream parsing dropped end tag for documentation")
 
     Document.parse_stream("<a.b> <c/> </a.b>", c)
